==> jc-1.4.0.tar.gz: soot/toolkits/graph/TrapUnitGraph.h <==
// public class soot.toolkits.graph.TrapUnitGraph

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 35d9fceef091cd7f soot_toolkits_graph_TrapUnitGraph
// @dep_class 91abf680ebee56a3 soot_toolkits_graph_UnitGraph

// header file dependencies
// @dep_header soot_toolkits_graph_UnitGraph

#include "soot/toolkits/graph/UnitGraph.h"

#ifndef _JC_soot_toolkits_graph_TrapUnitGraph_H_
#define _JC_soot_toolkits_graph_TrapUnitGraph_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_Body$object;

// Typedefs
typedef struct _jc_soot_toolkits_graph_TrapUnitGraph$sub_refs	_jc_soot_toolkits_graph_TrapUnitGraph$sub_refs;
typedef struct _jc_soot_toolkits_graph_TrapUnitGraph$sub_nonrefs	_jc_soot_toolkits_graph_TrapUnitGraph$sub_nonrefs;
typedef struct _jc_soot_toolkits_graph_TrapUnitGraph$refs	_jc_soot_toolkits_graph_TrapUnitGraph$refs;
typedef struct _jc_soot_toolkits_graph_TrapUnitGraph$nonrefs	_jc_soot_toolkits_graph_TrapUnitGraph$nonrefs;
typedef struct _jc_soot_toolkits_graph_TrapUnitGraph$object	_jc_soot_toolkits_graph_TrapUnitGraph$object;

typedef const struct _jc_soot_toolkits_graph_TrapUnitGraph$vmethods	_jc_soot_toolkits_graph_TrapUnitGraph$vmethods;
typedef const struct _jc_soot_toolkits_graph_TrapUnitGraph$vtable	_jc_soot_toolkits_graph_TrapUnitGraph$vtable;
typedef const struct _jc_soot_toolkits_graph_TrapUnitGraph$vtype	_jc_soot_toolkits_graph_TrapUnitGraph$vtype;

// Constructors
extern void _jc_soot_toolkits_graph_TrapUnitGraph$method$_init$3a6465c484af9c25(_jc_env *, struct _jc_soot_toolkits_graph_TrapUnitGraph$object *, struct _jc_soot_Body$object *);

// Virtual methods structure
struct _jc_soot_toolkits_graph_TrapUnitGraph$vmethods {
};

// Vtable
struct _jc_soot_toolkits_graph_TrapUnitGraph$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_toolkits_graph_UnitGraph$vmethods	soot_toolkits_graph_UnitGraph;
	_jc_soot_toolkits_graph_TrapUnitGraph$vmethods	soot_toolkits_graph_TrapUnitGraph;
};

// Vtype
struct _jc_soot_toolkits_graph_TrapUnitGraph$vtype {
	_jc_type			type;
	_jc_soot_toolkits_graph_TrapUnitGraph$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_toolkits_graph_TrapUnitGraph$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_toolkits_graph_TrapUnitGraph$refs {
    _jc_soot_toolkits_graph_TrapUnitGraph$sub_refs	soot_toolkits_graph_TrapUnitGraph;
    _jc_soot_toolkits_graph_UnitGraph$sub_refs	soot_toolkits_graph_UnitGraph;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_toolkits_graph_TrapUnitGraph$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_toolkits_graph_TrapUnitGraph$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_toolkits_graph_UnitGraph$sub_nonrefs	soot_toolkits_graph_UnitGraph;
    _jc_soot_toolkits_graph_TrapUnitGraph$sub_nonrefs	soot_toolkits_graph_TrapUnitGraph;
};

// Object instance structure
struct _jc_soot_toolkits_graph_TrapUnitGraph$object {
	_jc_soot_toolkits_graph_TrapUnitGraph$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_toolkits_graph_TrapUnitGraph$vtype	*vtype;
	_jc_soot_toolkits_graph_TrapUnitGraph$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_toolkits_graph_TrapUnitGraph$vtype _jc_soot_toolkits_graph_TrapUnitGraph$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_toolkits_graph_TrapUnitGraph, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_toolkits_graph_TrapUnitGraph$class_object;

#endif	/* _JC_soot_toolkits_graph_TrapUnitGraph_H_ */

==> jc-1.4.6.tar.gz: soot/toolkits/graph/TrapUnitGraph.h <==
// public class soot.toolkits.graph.TrapUnitGraph

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 35d9fceef091cd7f soot_toolkits_graph_TrapUnitGraph
// @dep_class 91abf680ebee56a3 soot_toolkits_graph_UnitGraph

// header file dependencies
// @dep_header soot_toolkits_graph_UnitGraph

#include "soot/toolkits/graph/UnitGraph.h"

#ifndef _JC_soot_toolkits_graph_TrapUnitGraph_H_
#define _JC_soot_toolkits_graph_TrapUnitGraph_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_Body$object;

// Typedefs
typedef struct _jc_soot_toolkits_graph_TrapUnitGraph$sub_refs	_jc_soot_toolkits_graph_TrapUnitGraph$sub_refs;
typedef struct _jc_soot_toolkits_graph_TrapUnitGraph$sub_nonrefs	_jc_soot_toolkits_graph_TrapUnitGraph$sub_nonrefs;
typedef struct _jc_soot_toolkits_graph_TrapUnitGraph$refs	_jc_soot_toolkits_graph_TrapUnitGraph$refs;
typedef struct _jc_soot_toolkits_graph_TrapUnitGraph$nonrefs	_jc_soot_toolkits_graph_TrapUnitGraph$nonrefs;
typedef struct _jc_soot_toolkits_graph_TrapUnitGraph$object	_jc_soot_toolkits_graph_TrapUnitGraph$object;

typedef const struct _jc_soot_toolkits_graph_TrapUnitGraph$vmethods	_jc_soot_toolkits_graph_TrapUnitGraph$vmethods;
typedef const struct _jc_soot_toolkits_graph_TrapUnitGraph$vtable	_jc_soot_toolkits_graph_TrapUnitGraph$vtable;
typedef const struct _jc_soot_toolkits_graph_TrapUnitGraph$vtype	_jc_soot_toolkits_graph_TrapUnitGraph$vtype;

// Constructors
extern void _jc_soot_toolkits_graph_TrapUnitGraph$method$_init$3a6465c484af9c25(_jc_env *, struct _jc_soot_toolkits_graph_TrapUnitGraph$object *, struct _jc_soot_Body$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_toolkits_graph_TrapUnitGraph$vmethods {
};

// Vtable
struct _jc_soot_toolkits_graph_TrapUnitGraph$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_toolkits_graph_UnitGraph$vmethods	soot_toolkits_graph_UnitGraph;
	_jc_soot_toolkits_graph_TrapUnitGraph$vmethods	soot_toolkits_graph_TrapUnitGraph;
};

// Vtype
struct _jc_soot_toolkits_graph_TrapUnitGraph$vtype {
	_jc_type			type;
	_jc_soot_toolkits_graph_TrapUnitGraph$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_toolkits_graph_TrapUnitGraph$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_toolkits_graph_TrapUnitGraph$refs {
    _jc_soot_toolkits_graph_TrapUnitGraph$sub_refs	soot_toolkits_graph_TrapUnitGraph;
    _jc_soot_toolkits_graph_UnitGraph$sub_refs	soot_toolkits_graph_UnitGraph;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_toolkits_graph_TrapUnitGraph$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_toolkits_graph_TrapUnitGraph$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_toolkits_graph_UnitGraph$sub_nonrefs	soot_toolkits_graph_UnitGraph;
    _jc_soot_toolkits_graph_TrapUnitGraph$sub_nonrefs	soot_toolkits_graph_TrapUnitGraph;
};

// Object instance structure
struct _jc_soot_toolkits_graph_TrapUnitGraph$object {
	_jc_soot_toolkits_graph_TrapUnitGraph$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_toolkits_graph_TrapUnitGraph$vtype	*vtype;
	_jc_soot_toolkits_graph_TrapUnitGraph$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_toolkits_graph_TrapUnitGraph$vtype _jc_soot_toolkits_graph_TrapUnitGraph$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_toolkits_graph_TrapUnitGraph, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_toolkits_graph_TrapUnitGraph$class_object;

#endif	/* _JC_soot_toolkits_graph_TrapUnitGraph_H_ */
